import { JSONSchema7, JSONSchema7TypeName } from "json-schema";
import { DPMConfiguration } from "./PackageUtil";
export interface RegistryReferenceV010 {
    url: string;
    catalogSlug: string;
}
export interface SourceV010 {
    type: string;
    uri: string;
    configuration?: DPMConfiguration;
    lastUpdateHash?: string;
}
export interface ValueTypeStatisticsV010 {
    valueType: JSONSchema7TypeName | "date";
    recordCount?: number;
    stringMaxLength?: number;
    stringMinLength?: number;
    numberMaxValue?: number;
    numberMinValue?: number;
    dateMaxValue?: Date;
    dateMinValue?: Date;
    stringOptions?: {
        [key: string]: number;
    };
}
export declare type PropertiesV010 = {
    [key: string]: SchemaV010;
};
export declare type ValueTypesV010 = {
    [key: string]: ValueTypeStatisticsV010;
};
export interface SchemaIdentifierV010 {
    registryUrl: string;
    catalogSlug: string;
    packageSlug: string;
    version: string;
    schemaTitle: string;
}
export interface DerivedFromV010 {
    displayName: string;
    url?: string;
    schemaIdentifier?: SchemaIdentifierV010;
}
export interface SchemaV010 extends JSONSchema7 {
    source?: SourceV010;
    properties?: PropertiesV010;
    unit?: string;
    recordCount?: number;
    recordsNotPresent?: number;
    recordCountApproximate?: boolean;
    byteCount?: number;
    byteCountApproximate?: boolean;
    valueTypes?: ValueTypesV010;
    sampleRecords?: {
        [key: string]: unknown;
    }[];
    derivedFromDescription?: string;
    derivedFrom?: DerivedFromV010[];
}
export interface PackageFileV010 {
    packageSlug: string;
    displayName: string;
    description: string;
    schemas: SchemaV010[];
    version: string;
    generatedBy: string;
    updatedDate: Date;
    readmeFile?: string;
    readmeMarkdown?: string;
    licenseFile?: string;
    licenseMarkdown?: string;
    website?: string;
    contactEmail?: string;
    registries?: RegistryReferenceV010[];
}
