import { JSONSchema7, JSONSchema7TypeName } from "json-schema";
import { DPMConfiguration } from "./main";
export interface RegistryReferenceV020 {
    url: string;
    catalogSlug: string;
}
export interface SourceV020 {
    type: string;
    uri: string;
    configuration?: DPMConfiguration;
    lastUpdateHash?: string;
}
export interface ValueTypeStatisticsV020 {
    valueType: JSONSchema7TypeName | "date";
    recordCount?: number;
    stringMaxLength?: number;
    stringMinLength?: number;
    numberMaxValue?: number;
    numberMinValue?: number;
    dateMaxValue?: Date;
    dateMinValue?: Date;
    stringOptions?: {
        [key: string]: number;
    };
}
export declare type PropertiesV020 = {
    [key: string]: SchemaV020;
};
export declare type ValueTypesV020 = {
    [key: string]: ValueTypeStatisticsV020;
};
export interface SchemaIdentifierV020 {
    registryUrl: string;
    catalogSlug: string;
    packageSlug: string;
    version: string;
    schemaTitle: string;
}
export interface DerivedFromV020 {
    displayName: string;
    url?: string;
    schemaIdentifier?: SchemaIdentifierV020;
}
export declare enum CountPrecisionV020 {
    EXACT = "EXACT",
    APPROXIMATE = "APPROXIMATE",
    GREATER_THAN = "GREATER_THAN"
}
export interface SchemaV020 extends JSONSchema7 {
    source?: SourceV020;
    properties?: PropertiesV020;
    unit?: string;
    recordsInspectedCount?: number;
    recordCount?: number;
    recordsNotPresent?: number;
    recordCountPrecision?: CountPrecisionV020;
    byteCount?: number;
    byteCountPrecision?: CountPrecisionV020;
    valueTypes?: ValueTypesV020;
    sampleRecords?: {
        [key: string]: unknown;
    }[];
    derivedFromDescription?: string;
    derivedFrom?: DerivedFromV020[];
}
export declare class PackageFileV020 {
    $schema: string;
    packageSlug: string;
    displayName: string;
    description: string;
    schemas: SchemaV020[];
    version: string;
    generatedBy: string;
    updatedDate: Date;
    readmeFile?: string;
    readmeMarkdown?: string;
    licenseFile?: string;
    licenseMarkdown?: string;
    website?: string;
    contactEmail?: string;
    registries?: RegistryReferenceV020[];
}
