"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const PackageUtil_1 = require("../src/PackageUtil");
const main_1 = require("../src/main");
const semver_1 = require("semver");
const chai_1 = require("chai");
describe("Checking VersionUtil", () => {
    it("Compatibility ENUM Order", () => {
        chai_1.expect(PackageUtil_1.leastCompatible(PackageUtil_1.Compability.Identical, PackageUtil_1.Compability.BreakingChange)).equal(PackageUtil_1.Compability.BreakingChange);
    });
    it("No change test", () => {
        const oldVersion = new semver_1.SemVer("1.0.3");
        const newVersion = PackageUtil_1.nextVersion(oldVersion, PackageUtil_1.Compability.Identical);
        chai_1.expect(oldVersion.version).equal("1.0.3");
        chai_1.expect(newVersion.version).equal("1.0.3");
    });
    it("Minor change test", () => {
        const oldVersion = new semver_1.SemVer("1.0.3");
        const newVersion = PackageUtil_1.nextVersion(oldVersion, PackageUtil_1.Compability.MinorChange);
        chai_1.expect(oldVersion.version).equal("1.0.3");
        chai_1.expect(newVersion.version).equal("1.0.4");
    });
    it("Compatible change test", () => {
        const oldVersion = new semver_1.SemVer("1.0.3");
        const newVersion = PackageUtil_1.nextVersion(oldVersion, PackageUtil_1.Compability.CompatibleChange);
        chai_1.expect(oldVersion.version).equal("1.0.3");
        chai_1.expect(newVersion.version).equal("1.1.0");
    });
    it("Breaking change test", () => {
        const oldVersion = new semver_1.SemVer("1.0.3");
        const newVersion = PackageUtil_1.nextVersion(oldVersion, PackageUtil_1.Compability.BreakingChange);
        chai_1.expect(oldVersion.version).equal("1.0.3");
        chai_1.expect(newVersion.version).equal("2.0.0");
    });
    it("Simple property schema comparison", () => {
        const schemaA1 = {
            title: "SchemaA",
            type: "string",
            format: "date-time"
        };
        const schemaA2 = {
            title: "SchemaA",
            type: "string",
            format: "date-time"
        };
        chai_1.expect(PackageUtil_1.compareSchema(schemaA1, schemaA2).length).equal(0);
        schemaA2.format = "date";
        const changeTitle = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(changeTitle[0].type).equal(PackageUtil_1.DifferenceType.CHANGE_PROPERTY_FORMAT);
    });
    it("Type arrays vs singluar values", () => {
        const schemaA1 = {
            title: "SchemaA",
            type: "object",
            properties: {
                string: { title: "string", type: "string" },
                number: { title: "number", type: "number" }
            }
        };
        const schemaA2 = {
            title: "SchemaA",
            type: "object",
            properties: {
                string: { title: "string", type: "string" },
                number: { title: "number", type: "number" }
            }
        };
        const diff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(diff.length).equal(0);
        schemaA1.properties.string.type = ["string", "number"];
        const arrayVsNotDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(arrayVsNotDiff.length).equal(1);
        chai_1.expect(arrayVsNotDiff[0].type).equal(PackageUtil_1.DifferenceType.CHANGE_PROPERTY_TYPE);
        schemaA2.properties.string.type = ["string", "number"];
        const equalDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(equalDiff.length).equal(0);
    });
    it("Object schema comparison", () => {
        const schemaA1 = {
            title: "SchemaA",
            type: "object",
            properties: {
                string: { title: "string", type: "string" },
                number: { title: "number", type: "number" }
            }
        };
        const schemaA2 = {
            title: "SchemaA",
            type: "object",
            properties: {
                string: { title: "string", type: "string" },
                number: { title: "number", type: "number" }
            }
        };
        const diff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(diff.length).equal(0);
        schemaA2.properties.boolean = { title: "boolean", type: "boolean" };
        const compatibleChange = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(compatibleChange.length).equal(1);
        chai_1.expect(compatibleChange[0].type).equal(PackageUtil_1.DifferenceType.ADD_PROPERTY);
        schemaA1.properties.date = {
            title: "date",
            type: "string",
            format: "date"
        };
        const addPropertyDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(addPropertyDiff.length).equal(2);
        const propertyRemoved = addPropertyDiff.find((d) => d.type === PackageUtil_1.DifferenceType.ADD_PROPERTY);
        chai_1.expect(propertyRemoved != null).equal(true);
        schemaA1.properties.boolean = { title: "boolean", type: "boolean" };
        schemaA2.properties.date = {
            title: "date",
            type: "string",
            format: "date"
        };
        const finalDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(finalDiff).length(0);
    });
    it("Diff compatibility testing", () => {
        chai_1.expect(PackageUtil_1.nextVersion(new semver_1.SemVer("1.0.2"), PackageUtil_1.Compability.BreakingChange).version).equal(new semver_1.SemVer("2.0.0").version);
        chai_1.expect(PackageUtil_1.nextVersion(new semver_1.SemVer("1.0.3"), PackageUtil_1.Compability.CompatibleChange).version).equal(new semver_1.SemVer("1.1.0").version);
        chai_1.expect(PackageUtil_1.nextVersion(new semver_1.SemVer("1.0.3"), PackageUtil_1.Compability.MinorChange).version).equal(new semver_1.SemVer("1.0.4").version);
    });
    it("Nested Objects Comparison", () => {
        const schemaA1 = {
            title: "SchemaA",
            type: "object",
            properties: {
                object: {
                    title: "object",
                    type: "object",
                    properties: {
                        string1: { type: "string" }
                    }
                },
                number: { title: "number", type: "number" }
            }
        };
        const schemaA2 = {
            title: "SchemaA",
            type: "object",
            properties: {
                object: {
                    title: "object",
                    type: "object",
                    properties: {
                        string1: { type: "string" }
                    }
                },
                number: { title: "number", type: "number" }
            }
        };
        const firstDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(firstDiff).length(0);
        chai_1.expect(PackageUtil_1.diffCompatibility(firstDiff)).equal(PackageUtil_1.Compability.Identical);
        schemaA2.properties.object.properties.string2 = { type: "string" };
        const compatibleDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(compatibleDiff).length(1);
        chai_1.expect(compatibleDiff[0].type).equal(PackageUtil_1.DifferenceType.ADD_PROPERTY);
        chai_1.expect(compatibleDiff[0].pointer).equal("#/SchemaA/properties/object/properties/string2");
        const compatibleComparison = PackageUtil_1.diffCompatibility(compatibleDiff);
        chai_1.expect(compatibleComparison).equal(PackageUtil_1.Compability.CompatibleChange);
        schemaA1.properties.object.properties.string3 = { type: "string" };
        const breakingDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(breakingDiff).length(2);
        chai_1.expect(breakingDiff[0].type).equal(PackageUtil_1.DifferenceType.REMOVE_PROPERTY);
        chai_1.expect(breakingDiff[0].pointer).equal("#/SchemaA/properties/object");
        chai_1.expect(breakingDiff[1].type).equal(PackageUtil_1.DifferenceType.ADD_PROPERTY);
        chai_1.expect(breakingDiff[1].pointer).equal("#/SchemaA/properties/object/properties/string2");
        const breakingChange = PackageUtil_1.diffCompatibility(breakingDiff);
        chai_1.expect(breakingChange).equal(PackageUtil_1.Compability.BreakingChange);
        schemaA1.properties.object.properties.string2 = { type: "string" };
        schemaA2.properties.object.properties.string3 = { type: "string" };
        const finalDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(finalDiff).length(0);
        chai_1.expect(PackageUtil_1.diffCompatibility(finalDiff)).equal(PackageUtil_1.Compability.Identical);
    });
    it("Catalog slug validation", () => {
        chai_1.expect(main_1.catalogSlugValid("a")).equal(true);
        chai_1.expect(main_1.catalogSlugValid("0")).equal(true);
        chai_1.expect(main_1.catalogSlugValid("a-b")).equal(true);
        chai_1.expect(main_1.catalogSlugValid("a-b-123")).equal(true);
        chai_1.expect(main_1.catalogSlugValid("a".repeat(39))).equal("CATALOG_SLUG_TOO_LONG");
        chai_1.expect(main_1.catalogSlugValid(undefined)).equal("CATALOG_SLUG_REQUIRED");
        chai_1.expect(main_1.catalogSlugValid("")).equal("CATALOG_SLUG_REQUIRED");
        chai_1.expect(main_1.catalogSlugValid("a_b")).equal("CATALOG_SLUG_INVALID");
        chai_1.expect(main_1.catalogSlugValid("a--b")).equal("CATALOG_SLUG_INVALID");
        chai_1.expect(main_1.catalogSlugValid("a-b-")).equal("CATALOG_SLUG_INVALID");
        chai_1.expect(main_1.catalogSlugValid("-a-b")).equal("CATALOG_SLUG_INVALID");
    });
    it("Package slug validation", () => {
        chai_1.expect(main_1.packageSlugValid("a")).equal(true);
        chai_1.expect(main_1.packageSlugValid("0")).equal(true);
        chai_1.expect(main_1.packageSlugValid("a.b")).equal(true);
        chai_1.expect(main_1.packageSlugValid("a--b")).equal(true);
        chai_1.expect(main_1.packageSlugValid("a__b")).equal(true);
        chai_1.expect(main_1.packageSlugValid("a__b----c.123")).equal(true);
        chai_1.expect(main_1.packageSlugValid("a".repeat(100))).equal("PACKAGE_SLUG_TOO_LONG");
        chai_1.expect(main_1.packageSlugValid(undefined)).equal("PACKAGE_SLUG_REQUIRED");
        chai_1.expect(main_1.packageSlugValid("")).equal("PACKAGE_SLUG_REQUIRED");
        chai_1.expect(main_1.packageSlugValid(".")).equal("PACKAGE_SLUG_INVALID");
        chai_1.expect(main_1.packageSlugValid("-")).equal("PACKAGE_SLUG_INVALID");
        chai_1.expect(main_1.packageSlugValid("_")).equal("PACKAGE_SLUG_INVALID");
        chai_1.expect(main_1.packageSlugValid("a@b")).equal("PACKAGE_SLUG_INVALID");
        chai_1.expect(main_1.packageSlugValid("a.")).equal("PACKAGE_SLUG_INVALID");
        chai_1.expect(main_1.packageSlugValid("a..b")).equal("PACKAGE_SLUG_INVALID");
        chai_1.expect(main_1.packageSlugValid("a-")).equal("PACKAGE_SLUG_INVALID");
        chai_1.expect(main_1.packageSlugValid("a_")).equal("PACKAGE_SLUG_INVALID");
        chai_1.expect(main_1.packageSlugValid("a___c")).equal("PACKAGE_SLUG_INVALID");
    });
    it("Collection slug validation", () => {
        chai_1.expect(main_1.collectionSlugValid("a")).equal(true);
        chai_1.expect(main_1.collectionSlugValid("a--b")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("a__b")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("a__b----c.123")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("a".repeat(101))).equal("COLLECTION_SLUG_TOO_LONG");
        chai_1.expect(main_1.collectionSlugValid(undefined)).equal("COLLECTION_SLUG_REQUIRED");
        chai_1.expect(main_1.collectionSlugValid("a.b")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("")).equal("COLLECTION_SLUG_REQUIRED");
        chai_1.expect(main_1.collectionSlugValid("0")).equal(true);
        chai_1.expect(main_1.collectionSlugValid(".")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("-")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("_")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("a@b")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("a.")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("a..b")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("a-")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("a_")).equal("COLLECTION_SLUG_INVALID");
        chai_1.expect(main_1.collectionSlugValid("a___c")).equal("COLLECTION_SLUG_INVALID");
    });
    it("Compare identical schemas", () => {
        const schemaA1 = {
            title: "SchemaA",
            type: "string",
            format: "date-time"
        };
        const schemaA2 = {
            title: "SchemaA",
            type: "string",
            format: "date-time"
        };
        const diffs = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        console.log(JSON.stringify(diffs, null, 1));
        chai_1.expect(diffs.length).equal(0);
    });
    it("Compare source objects", () => {
        const sourceA = {
            slug: "datapm",
            type: "test",
            uris: ["http://datapm.io/test", "http://datapm.io/test2"],
            configuration: {},
            streamSets: [
                {
                    configuration: {},
                    slug: "streamA",
                    lastUpdateHash: "abc123",
                    schemaTitles: ["A"],
                    streamStats: {
                        inspectedCount: 0
                    }
                }
            ]
        };
        const sourceB = {
            slug: "datapm",
            type: "test",
            uris: ["http://datapm.io/test", "http://datapm.io/test2"],
            configuration: {},
            streamSets: [
                {
                    configuration: {},
                    slug: "streamA",
                    lastUpdateHash: "abc123",
                    schemaTitles: ["A"],
                    streamStats: {
                        inspectedCount: 0
                    }
                }
            ]
        };
        const diffs = main_1.compareSource(sourceA, sourceB);
        chai_1.expect(diffs.length).equals(0);
        sourceA.streamSets[0].lastUpdateHash = "test";
        const diffs2 = main_1.compareSource(sourceA, sourceB);
        chai_1.expect(diffs2[0].type).equal(PackageUtil_1.DifferenceType.CHANGE_STREAM_UPDATE_HASH);
        sourceA.streamSets[0].lastUpdateHash = sourceB.streamSets[0].lastUpdateHash;
        sourceA.uris = ["http://datapm.io.test"];
        const diffs3 = main_1.compareSource(sourceA, sourceB);
        chai_1.expect(diffs3[0].type).equal(PackageUtil_1.DifferenceType.CHANGE_SOURCE_URIS);
    });
    it("Compare source arrays", () => {
        const sourceA = [
            {
                slug: "datapm",
                type: "test",
                uris: ["http://datapm.io/test", "http://datapm.io/test2"],
                configuration: {},
                streamSets: [
                    {
                        configuration: {},
                        slug: "streamA",
                        lastUpdateHash: "abc123",
                        schemaTitles: ["A"],
                        streamStats: {
                            inspectedCount: 0
                        }
                    }
                ]
            }
        ];
        const sourceB = [
            {
                slug: "datapm",
                type: "test",
                uris: ["http://datapm.io/test", "http://datapm.io/test2"],
                configuration: {},
                streamSets: [
                    {
                        configuration: {},
                        slug: "streamA",
                        lastUpdateHash: "abc123",
                        schemaTitles: ["A"],
                        streamStats: {
                            inspectedCount: 0
                        }
                    }
                ]
            }
        ];
        const diffs = main_1.compareSources(sourceA, sourceB);
        chai_1.expect(diffs.length).equals(0);
        sourceA[0].uris = ["test"];
        const diffs2 = main_1.compareSources(sourceA, sourceB);
        chai_1.expect(diffs2[0].type).equal(PackageUtil_1.DifferenceType.CHANGE_SOURCE_URIS);
    });
    it("Detected removed sources", () => {
        const sourceA = [
            {
                slug: "datapm",
                type: "test",
                uris: ["http://datapm.io/test", "http://datapm.io/test2"],
                configuration: {},
                streamSets: [
                    {
                        configuration: {},
                        slug: "streamA",
                        lastUpdateHash: "abc123",
                        schemaTitles: ["A"],
                        streamStats: {
                            inspectedCount: 0
                        }
                    }
                ]
            }
        ];
        const sourceB = [
            {
                slug: "datapm2",
                type: "test",
                uris: ["http://datapm.io/test", "http://datapm.io/test2"],
                configuration: {},
                streamSets: [
                    {
                        configuration: {},
                        slug: "streamA",
                        lastUpdateHash: "abc123",
                        schemaTitles: ["A"],
                        streamStats: {
                            inspectedCount: 0
                        }
                    }
                ]
            }
        ];
        const diffs = main_1.compareSources(sourceA, sourceB);
        chai_1.expect(diffs.length).equals(1);
        chai_1.expect(diffs[0].type).equals(PackageUtil_1.DifferenceType.REMOVE_SOURCE);
    });
    it("Stream status change detection", () => {
        const sourceA = [
            {
                slug: "datapm",
                type: "test",
                uris: ["http://datapm.io/test", "http://datapm.io/test2"],
                configuration: {},
                streamSets: [
                    {
                        slug: "test",
                        configuration: {},
                        lastUpdateHash: "abc123",
                        schemaTitles: ["A"],
                        streamStats: {
                            inspectedCount: 0
                        }
                    }
                ]
            }
        ];
        const sourceB = [
            {
                slug: "datapm",
                type: "test",
                uris: ["http://datapm.io/test", "http://datapm.io/test2"],
                configuration: {},
                streamSets: [
                    {
                        slug: "test",
                        configuration: {},
                        lastUpdateHash: "abc123",
                        schemaTitles: ["A"],
                        streamStats: {
                            inspectedCount: 1
                        }
                    }
                ]
            }
        ];
        const diffs = main_1.compareSources(sourceA, sourceB);
        chai_1.expect(diffs.length).equals(1);
        chai_1.expect(diffs[0].type).equal(PackageUtil_1.DifferenceType.CHANGE_STREAM_STATS);
        sourceB[0].streamSets[0].slug += "!";
        const diffs2 = main_1.compareSources(sourceA, sourceB);
        chai_1.expect(diffs2.length).equals(1);
        chai_1.expect(diffs2[0].type).equal(PackageUtil_1.DifferenceType.REMOVE_STREAM_SET);
    });
    it("Source configuration detection", () => {
        const sourceA = [
            {
                slug: "datapm",
                type: "test",
                uris: ["http://datapm.io/test", "http://datapm.io/test2"],
                configuration: {},
                streamSets: [
                    {
                        slug: "test",
                        configuration: {},
                        lastUpdateHash: "abc123",
                        schemaTitles: ["A"],
                        streamStats: {
                            inspectedCount: 1
                        }
                    }
                ]
            }
        ];
        const sourceB = [
            {
                slug: "datapm",
                type: "test",
                uris: ["http://datapm.io/test", "http://datapm.io/test2"],
                configuration: {
                    newValue: "a"
                },
                streamSets: [
                    {
                        slug: "test",
                        configuration: {},
                        lastUpdateHash: "abc123",
                        schemaTitles: ["A"],
                        streamStats: {
                            inspectedCount: 1
                        }
                    }
                ]
            }
        ];
        const diffs = main_1.compareSources(sourceA, sourceB);
        chai_1.expect(diffs.length).equals(1);
        chai_1.expect(diffs[0].type).equal(PackageUtil_1.DifferenceType.CHANGE_SOURCE_CONFIGURATION);
    });
    it("Package File updated dates", function () {
        const packageFileA = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            version: "1.0.0",
            updatedDate: new Date(),
            description: "Back test",
            sources: []
        };
        const packageFileB = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            version: "1.0.0",
            updatedDate: packageFileA.updatedDate,
            description: "Back test",
            sources: []
        };
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === "CHANGE_UPDATED_DATE")).equal(false);
        packageFileB.updatedDate = new Date(new Date().getTime() - 100);
        const diff = PackageUtil_1.comparePackages(packageFileA, packageFileB);
        chai_1.expect(diff.some((d) => d.type === "CHANGE_UPDATED_DATE")).equal(true);
    });
    it("Package File updated versions", function () {
        const packageFileA = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: new Date(),
            description: "Back test"
        };
        const packageFileB = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: packageFileA.updatedDate,
            description: "Back test"
        };
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === "CHANGE_VERSION")).equal(false);
        packageFileB.version = "1.0.1";
        const diff = PackageUtil_1.comparePackages(packageFileA, packageFileB);
        chai_1.expect(diff.some((d) => d.type === "CHANGE_VERSION")).equal(true);
    });
    it("Package File updated readme", function () {
        const packageFileA = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: new Date(),
            description: "Back test",
            readmeMarkdown: "Some readme content"
        };
        const packageFileB = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: packageFileA.updatedDate,
            description: "Back test",
            readmeMarkdown: packageFileA.readmeMarkdown
        };
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_README_MARKDOWN)).equal(false);
        packageFileB.readmeFile = "some-new-file.README.md";
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_README_FILE)).equal(true);
        packageFileB.readmeMarkdown = "other content";
        const diff = PackageUtil_1.comparePackages(packageFileA, packageFileB);
        chai_1.expect(diff.some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_README_MARKDOWN)).equal(true);
    });
    it("Package File updated license", function () {
        const packageFileA = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: new Date(),
            description: "Back test",
            licenseMarkdown: "Some content"
        };
        const packageFileB = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: packageFileA.updatedDate,
            description: "Back test",
            licenseMarkdown: packageFileA.licenseMarkdown
        };
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_LICENSE_MARKDOWN)).equal(false);
        packageFileB.licenseFile = "some-new-file.LICENSE.md";
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_LICENSE_FILE)).equal(true);
        packageFileB.licenseMarkdown = "other content";
        const diff = PackageUtil_1.comparePackages(packageFileA, packageFileB);
        chai_1.expect(diff.some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_LICENSE_MARKDOWN)).equal(true);
    });
    it("Package File updated contact email", function () {
        const packageFileA = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: new Date(),
            description: "Back test",
            readmeMarkdown: "Some readme content",
            contactEmail: "test@test.com"
        };
        const packageFileB = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: packageFileA.updatedDate,
            description: "Back test",
            readmeMarkdown: packageFileA.readmeMarkdown,
            contactEmail: packageFileA.contactEmail
        };
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_CONTACT_EMAIL)).equal(false);
        packageFileB.contactEmail = "testb@test.com";
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_CONTACT_EMAIL)).equal(true);
    });
    it("Package File updated website", function () {
        const packageFileA = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: new Date(),
            description: "Back test",
            readmeMarkdown: "Some readme content",
            contactEmail: "test@test.com",
            website: "https://dreamingwell.com"
        };
        const packageFileB = {
            ...new main_1.PackageFile(),
            packageSlug: "test",
            displayName: "test",
            generatedBy: "test",
            schemas: [],
            sources: [],
            version: "1.0.0",
            updatedDate: packageFileA.updatedDate,
            description: "Back test",
            readmeMarkdown: packageFileA.readmeMarkdown,
            contactEmail: packageFileA.contactEmail,
            website: packageFileA.website
        };
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_WEBSITE)).equal(false);
        packageFileB.website = "https://datapm.io";
        chai_1.expect(PackageUtil_1.comparePackages(packageFileA, packageFileB).some((d) => d.type === PackageUtil_1.DifferenceType.CHANGE_WEBSITE)).equal(true);
    });
    it("Compare hidden properties", () => {
        const schemaA1 = {
            title: "SchemaA",
            type: "object",
            properties: {
                string: { title: "string", type: "string" },
                number: { title: "number", type: "number" }
            }
        };
        const schemaA2 = {
            title: "SchemaA",
            type: "object",
            properties: {
                string: { title: "string", type: "string" },
                number: { title: "number", type: "number" }
            }
        };
        const diff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(diff.length).equal(0);
        schemaA2.properties.string.hidden = true;
        const propertyHiddenDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(propertyHiddenDiff.length).equal(1);
        chai_1.expect(propertyHiddenDiff[0].type).equal(PackageUtil_1.DifferenceType.HIDE_PROPERTY);
        const propertyHiddenCompatibility = PackageUtil_1.diffCompatibility(propertyHiddenDiff);
        chai_1.expect(propertyHiddenCompatibility).equal(PackageUtil_1.Compability.BreakingChange);
        schemaA1.properties.string.hidden = true;
        delete schemaA2.properties.string;
        const removeHiddenPropertyDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(removeHiddenPropertyDiff.length).equal(1);
        chai_1.expect(removeHiddenPropertyDiff[0].type).equal(PackageUtil_1.DifferenceType.REMOVE_HIDDEN_PROPERTY);
        const removeHiddenPropertyCompatibility = PackageUtil_1.diffCompatibility(removeHiddenPropertyDiff);
        chai_1.expect(removeHiddenPropertyCompatibility).equal(PackageUtil_1.Compability.MinorChange);
    });
    it("Compare changing property unit", () => {
        const schemaA1 = {
            title: "SchemaA",
            type: "object",
            properties: {
                string: { title: "string", type: "string" },
                number: { title: "number", type: "number", unit: "something" }
            }
        };
        const schemaA2 = {
            title: "SchemaA",
            type: "object",
            properties: {
                string: { title: "string", type: "string" },
                number: { title: "number", type: "number", unit: "something" }
            }
        };
        const diff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(diff.length).equal(0);
        schemaA2.properties.number.unit = "something else";
        const propertyHiddenDiff = PackageUtil_1.compareSchema(schemaA1, schemaA2);
        chai_1.expect(propertyHiddenDiff.length).equal(1);
        chai_1.expect(propertyHiddenDiff[0].type).equal(PackageUtil_1.DifferenceType.CHANGE_PROPERTY_UNIT);
        const propertyHiddenCompatibility = PackageUtil_1.diffCompatibility(propertyHiddenDiff);
        chai_1.expect(propertyHiddenCompatibility).equal(PackageUtil_1.Compability.MinorChange);
    });
});
//# sourceMappingURL=PackageComparison.spec.js.map