"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const main_1 = require("../src/main");
const chai_1 = require("chai");
const fs_1 = __importDefault(require("fs"));
describe("PackageFile checks", () => {
    it("Should have correct schema value", function () {
        const test = new main_1.PackageFile();
        chai_1.expect(test.$schema).equal("https://datapm.io/docs/package-file-schema-v0.3.0.json");
    });
    it("Should parse dates", function () {
        const packageFileString = fs_1.default.readFileSync("test/packageFiles/congressional-legislators.datapm.json");
        const packageFile = main_1.parsePackageFileJSON(packageFileString.toString());
        chai_1.expect(packageFile.updatedDate.getTime()).equals(1601560469442);
    });
    it("Should load readme and license files", function () {
        const packageFile = main_1.loadPackageFileFromDisk("test/packageFiles/congressional-legislators.datapm.json");
        chai_1.expect(packageFile.updatedDate.getTime()).equals(1601560469442);
        chai_1.expect(packageFile.readmeMarkdown).contains("This is where a readme might go.");
        chai_1.expect(packageFile.licenseMarkdown).contains("This is not a real license. Just a test.");
    });
    it("Should have v0.3.0 sources array separate from schemas", function () {
        const packageFile = main_1.loadPackageFileFromDisk("test/packageFiles/congressional-legislators.datapm.json");
        chai_1.expect(packageFile.sources.length).equal(1);
        chai_1.expect(packageFile.sources[0].uris.length).equal(1);
        chai_1.expect(packageFile.sources[0].uris[0]).equal("https://theunitedstates.io/congress-legislators/legislators-current.csv");
    });
    it("Should throw invalid package file error", function () {
        const packageFile = main_1.loadPackageFileFromDisk("test/packageFiles/congressional-legislators.datapm.json");
        packageFile.packageSlug += "-";
        const invalidPackageFileString = JSON.stringify(packageFile);
        let errorFound = false;
        try {
            main_1.validatePackageFile(invalidPackageFileString);
        }
        catch (error) {
            errorFound = true;
        }
        chai_1.expect(errorFound).equal(true);
    });
});
//# sourceMappingURL=PackageFileParse.spec.js.map